@@ -17,10 +17,6 @@
 #ifndef MYMONEYACCOUNT_H
 #define MYMONEYACCOUNT_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -34,14 +30,14 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
+#include <kmymoney/export.h>
 #include <kmymoney/mymoneymoney.h>
 #include <kmymoney/mymoneyobject.h>
 #include <kmymoney/mymoneykeyvaluecontainer.h>
 #include <kmymoney/mymoneysecurity.h>
+#include <kmymoney/mymoneyutils.h>
 #include <kmymoney2/views/kmymoneytransaction.h>
 #include <kmymoney2/mymoney/mymoneysplit.h>
-#include <kmymoney/export.h>
-#include "mymoneyutils.h"
 class MyMoneyTransaction;
 class MyMoneyInstitution;
 class MyMoneySplit;
