@@ -30,7 +30,7 @@ class TQLabel;
 // ----------------------------------------------------------------------------
 // Project Includes
 
-#include "../widgets/kbudgetvaluesdecl.h"
+#include <kmymoney/kbudgetvaluesdecl.h>
 #include <kmymoney/mymoneybudget.h>
 class kMyMoneyEdit;
 
